/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task;

import java.awt.event.ActionEvent;
import java.util.HashMap;
import java.util.List;
import javax.swing.AbstractAction;
import org.openide.awt.ActionID;
import org.openide.awt.ActionRegistration;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 *
 * @author Johan Reitzema
 * @author Maciek Dulkiewicz
 */
@ActionID(category = "ExportableTask", id = "nl.cloudfarming.client.isobus.type.ExportAction")
@ActionRegistration(displayName = "#isobus.action.export")
@NbBundle.Messages({
    "isobus.action.export=Export Isobus",
    "isobus.action.progress_handler_msg=Exporting Isobus task data",
    "isobus.action.confirm_overwrite_taskdata=Overwrite current taskdata folder contents?"    
})
public class ExportAction extends AbstractAction {

    
    private final List<ExportableTaskCapability> exportCapabilities;


    public ExportAction(List<ExportableTaskCapability> exportCapabilities) {
        super(NbBundle.getMessage(ExportAction.class, "isobus.action.export"));
        this.exportCapabilities = exportCapabilities;
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        //TODO what to do with multiple implemenmtations?
        TaskExporter exporter = Lookup.getDefault().lookup(TaskExporter.class);
        ExportableTask[] tasks = new ExportableTask[exportCapabilities.size()];
        int i=0;
        for (ExportableTaskCapability capability: exportCapabilities){
            tasks[i++]=capability.getTask();
        }
        exporter.exportTask(new HashMap<String,Object>(),tasks);

    }
}
